# frozen_string_literal: true

$LOAD_PATH.unshift File.expand_path('lib', __dir__)
require 'base32/version'

Gem::Specification.new do |spec|
  spec.name     = 'base32.rb'
  spec.version  = Base32::VERSION
  spec.license  = 'MIT'
  spec.homepage = 'https://github.com/ydakuka/base32.rb'
  spec.summary  = 'Ruby extension for base32 encoding and decoding.'
  spec.platform = Gem::Platform::RUBY

  spec.authors = ['Samuel Tesla']
  spec.email   = 'samuel.tesla@gmail.com'

  spec.description = <<-DESCRIPTION.split.join ' '
    Base32 is one of several base 32 transfer encodings. Base32 uses a
    32-character set comprising the twenty-six upper-case letters A–Z,
    and the digits 2–7.

    Base32 is primarily used to encode binary data, but Base32 is also able to
    encode binary text like ASCII.

    Base32 is a notation for encoding arbitrary byte data using a restricted set
    of symbols that can be conveniently used by humans and processed by
    computers.

    Base32 consists of a symbol set made up of 32 different characters, as well
    as an algorithm for encoding arbitrary sequences of 8-bit bytes into the
    Base32 alphabet. Because more than one 5-bit Base32 symbol is needed to
    represent each 8-bit input byte, it also specifies requirements on the
    allowed lengths of Base32 strings (which must be multiples of 40 bits). The
    closely related Base64 system, in contrast, uses a set of 64 symbols.
  DESCRIPTION

  spec.metadata = {
    'homepage_uri' => 'https://github.com/ydakuka/base32.rb',
    'source_code_uri' => 'https://github.com/ydakuka/base32.rb',
    'bug_tracker_uri' => 'https://github.com/ydakuka/base32.rb/issues',
  }.freeze

  spec.require_paths = ['lib']

  spec.files         = `git ls-files`.split("\n")
  spec.test_files    = `git ls-files -- {test,spec,features}/*`.split("\n")

  spec.executables = spec.files.grep(%r{^bin/}) { |f| File.basename(f) }

  spec.add_development_dependency 'gem-release',         '~> 2.0'
  spec.add_development_dependency 'minitest',            '~> 5.11'
  spec.add_development_dependency 'rake',                '~> 12.3'
  spec.add_development_dependency 'rubocop',             '~> 0.73'
  spec.add_development_dependency 'rubocop-performance', '~> 1.5'
end
